@@ -21,13 +21,12 @@ pub mod commitment;
 pub mod contains;
 pub mod cost_model;
 pub mod cost_tracker;
-pub mod cost_tracker_stats;
 pub mod epoch_stakes;
 pub mod execute_cost_table;
 pub mod genesis_utils;
 pub mod hardened_unpack;
 pub mod hashed_transaction;
-pub mod inline_spl_token_v2_0;
+pub mod inline_spl_token;
 pub mod instruction_recorder;
 pub mod loader_utils;
 pub mod log_collector;
