@@ -1,9 +1,11 @@
-use super::common::UnusedAccounts;
 #[cfg(all(test, RUSTC_WITH_SPECIALIZATION))]
 use solana_frozen_abi::abi_example::IgnoreAsHelper;
-use {super::*, solana_measure::measure::Measure, std::cell::RefCell};
-
-use crate::ancestors::AncestorsForSerialization;
+use {
+    super::{common::UnusedAccounts, *},
+    crate::ancestors::AncestorsForSerialization,
+    solana_measure::measure::Measure,
+    std::cell::RefCell,
+};
 
 type AccountsDbFields = super::AccountsDbFields<SerializableAccountStorageEntry>;
 
