@@ -1,8 +1,7 @@
-use crate::accounts_db::SnapshotStorage;
-use log::*;
-use solana_measure::measure::Measure;
-use solana_sdk::clock::Slot;
-use std::ops::Range;
+use {
+    crate::accounts_db::SnapshotStorage, log::*, solana_measure::measure::Measure,
+    solana_sdk::clock::Slot, std::ops::Range,
+};
 
 pub struct SortedStorages<'a> {
     range: Range<Slot>,
